@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2021 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2021-2025 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software. It comes without any warranty, to
@@ -10,7 +10,7 @@
 # http://www.wtfpl.net/ for more details.
 
 package Chess::Plisco::Engine::InputWatcher;
-$Chess::Plisco::Engine::InputWatcher::VERSION = '0.2.0';
+$Chess::Plisco::Engine::InputWatcher::VERSION = 'v0.7.0';
 use strict;
 
 use IO::Select;
@@ -22,11 +22,20 @@ sub new {
 	my $sel = IO::Select->new($fh);
 
 	bless {
+		__handle => $fh,
 		__sel => $sel,
 		__input => '',
 	}, $class;
 }
 
+sub setBatchMode {
+	my ($self, $mode) = @_;
+
+	$self->{__batch_mode} = $mode;
+
+	return $self;
+}
+
 sub onInput {
 	my ($self, $cb) = @_;
 
@@ -44,12 +53,15 @@ sub onEof {
 sub check {
 	my ($self) = @_;
 
+	return if $self->{__batch_mode};
+
 	while (my @ready = $self->{__sel}->can_read(0)) {
 		foreach my $fh (@ready) {
 			my $offset = length $self->{__input};
-			my $bytes = $fh->sysread($self->{__input}, 2, $offset);
+			my $bytes = $fh->sysread($self->{__input}, 1, $offset);
 			if (!$bytes) {
 				$self->{__on_eof}->() if $self->{__on_eof};
+				return;
 			} elsif ($self->{__input} =~ s/^(.*?)\n//) {
 				$self->{__on_input}->($1) if $self->{__on_input};
 			}
