@@ -1,6 +1,6 @@
 #! /bin/false
 
-# Copyright (C) 2021 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2021-2025 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software. It comes without any warranty, to
@@ -13,7 +13,7 @@
 # ABSTRACT: Analyze chess games in PGN format
 
 package Chess::Plisco::Engine::TimeControl;
-$Chess::Plisco::Engine::TimeControl::VERSION = '0.2.0';
+$Chess::Plisco::Engine::TimeControl::VERSION = 'v0.7.0';
 use strict;
 
 use Time::HiRes qw(gettimeofday);
@@ -57,11 +57,11 @@ sub new {
 
 	if ($params{movetime}) {
 		$tree->{allocated_time} = $params{movetime};
+		$tree->{fixed_time} = 1;
 	} elsif ($params{infinite}) {
-		$tree->{nodes_to_tc} = -1;
+		$tree->{max_depth} = Plisco::Engine::Tree->MAX_PLY;
 	} elsif ($params{nodes}) {
-		$tree->{nodes_to_tc} = $params{nodes};
-		$tree->{allocated_time} = 0;
+		$tree->{max_nodes} = $params{nodes};
 	} elsif ($params{mytime}) {
 		$self->allocateTime($tree, \%params);
 	}
